@@ -6,7 +6,7 @@ WWW::Phanfare::API - Perl wrapper for Phanfare API
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
@@ -17,8 +17,9 @@ use REST::Client;
 use Digest::MD5 qw(md5_hex);
 use URI::Escape;
 use XML::Simple;
+use File::Slurp;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 our $site = 'http://www.phanfare.com/api/?';
 our $AUTOLOAD;
 
@@ -71,8 +72,16 @@ sub AUTOLOAD {
     $self->{_rest}->getUseragent()->cookie_jar({});
   }
 
+  # Include an image for upload?
+  my $image = read_file($param{filename}, binmode => ':raw')
+    if $param{filename};
+
   # Send request
-  $self->{_rest}->GET( $site . $req );
+  if ( $image ) {
+    $self->{_rest}->PUT( $site.$req, $image );
+  } else {
+    $self->{_rest}->GET( $site.$req );
+  }
 
   # Receive response
   carp sprintf(
@@ -90,7 +99,7 @@ sub DESTROY {}
 
 =head1 SYNOPSIS
 
-Create object. Developer API keys required.
+Create agent. Developer API keys required.
 
     use WWW::Phanfare::API;
     my $papi = WWW::Phanfare::API->new(
@@ -106,12 +115,13 @@ Authentication with account:
     )
     die "Cannot authenticate: $session->{code_value}"
       unless $session->{'stat'} eq 'ok';
+    my $target_uid = $session->{session}{uid};
  
 Or authenticate as guest:
 
     $papi->AuthenticateGuest();
 
-List of albums:
+Get list of albums:
 
     my $albumlist = $papi->GetAlbumList(
       target_uid => $session->{session}{uid}
@@ -122,6 +132,28 @@ List of albums:
       $_->{album_id}, substr($_->{album_start_date}, 0, 10), $_->{album_name}
     ) for @$albumlist;
 
+Create new album, upload an image to it and delete it all again.
+
+    my $album = $papi->NewAlbum(
+      target_uid => $target_uid,
+    );
+
+    my $album_id   = $album->{album}{album_id};
+    my $section_id = $album->{album}{sections}{section}{section_id};
+
+    my $image = $papi->NewImage(
+      target_uid => $target_uid,
+      album_id   => $album_id,
+      section_id => $section_id,
+      filename   => 'IMG_1234.jpg',
+    );
+
+    my $del_album = $api->DeleteAlbum(
+      target_uid => $target_uid,
+      album_id   => $album_id,
+    );
+
+
 =head1 DESCRIPTION
 
 Perl wrapper the Phanfare API. A developer API key is required for using
